Learn R Programming

CompositionalSR (version 1.1)

The gradient vector of the alpha-SLX model at each observation: The gradient vector of the \(\alpha\)-SLX model at each observation

Description

The gradient vector of the \(\alpha\)-SLX model at each observation.

Usage

aslx.grads(y, x, a, be, gama, coords, k = 10)

Value

A matrix with the gradient vector computed at each observation.

Arguments

y

A matrix with the compositional data.

x

A matrix with the continuous predictor variables or a data frame including categorical predictor variables.

a

The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0.

be

The regression coefficients of the \(\alpha\)-SLX model.

gama

The gamma coefficients of the \(\alpha\)-SLX model.

coords

A matrix with the coordinates of the locations. The first column is the latitude and the second is the longitude.

k

The number of nearest neighbours to consider for the contiguity matrix.

Author

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

Details

The gradient vector of the \(\alpha\)-SLX model is computed at each observation.

References

Tsagris M. (2025). The \(\alpha\)--regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663

Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

See Also

alfa.sar, cv.alfasar, alfa.reg

Examples

Run this code
data(fadn)
coords <- fadn[, 1:2]
y <- fadn[, 3:7]
x <- fadn[, 8]
mod <- alfa.slx(y, x, a = 0.5, coords, k = 10)
grads <- aslx.grads(y, x, a = 0.5, mod$be, mod$gama, coords, k = 10)
colSums(grads)

Run the code above in your browser using DataLab