alfa.pcreg: Compositional regression with compositional predictors using...

View source: R/alfa.pcreg.R

Compositional regression with compositional predictors using the alpha-transformationR Documentation

Compositional regression with compositional predictors using the \alpha-transformation

Description

Compositional regression with compositional predictors using the \alpha-transformation.

Usage

alfa.pcreg(y, x, a, k, xnew = NULL, yb = NULL)

Arguments

y

A matrix with the compositional responses. Zero values are allowed.

x

A matrix with the compositional predictors. Zero values are allowed.

a

The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0. If \alpha=0 the isometric log-ratio transformation is applied and the solution exists in a closed form, since it the classical mutivariate regression.

k

How many principal components to compute?

xnew

If you have new data use it, otherwise leave it NULL.

yb

If you have already transformed the data using the \alpha-transformation with the same \alpha as given in the argument "a", put it here. Othewrise leave it NULL.

Details

The \alpha-transformation is applied to both the compositional responses and predictors. Then, principal component analysis is performed in the \alpha-transformed predictors and the projected scores are used a predictors. The same value of \alpha is used for both the responses and the predictors.

Value

A list including:

runtime

The time required by the regression.

be

The beta coefficients.

dev

The sum of the squared residuals, as produced by the function minpack.lm::nls.lm().

est

The fitted values for xnew if xnew is not NULL.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663

Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

Mardia K.V., Kent J.T., and Bibby J.M. (1979). Multivariate analysis. Academic press.

See Also

cv.alfapcreg, areg

Examples

data(fadn)
y <- fadn[, 3:7]
x <- fadn[, 8:11]
x <- x / rowSums(x)
mod <- alfa.pcreg(y, x, k = 3, 0.2)

CompositionalSR documentation built on March 28, 2026, 5:07 p.m.