asar.grads: The gradient vector of the alpha-SAR model at each...

View source: R/asar.grads.R

The gradient vector of the alpha-SAR model at each observationR Documentation

The gradient vector of the \alpha-SAR model at each observation

Description

The gradient vector of the \alpha-SAR model at each observation.

Usage

asar.grads(y, x, a, rho, be, coords, k)

Arguments

y

A matrix with the compositional data.

x

A matrix with the continuous predictor variables or a data frame including categorical predictor variables.

a

The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0.

rho

The spatial autocorrelation parameter \rho.

be

The regression coefficients of the \alpha-SAR model.

coords

A matrix with the coordinates of the locations. The first column is the latitude and the second is the longitude.

k

The number of nearest neighbours to consider for the contiguity matrix.

Details

The gradient vector of the \alpha-SAR model is computed at each observation.

Value

A matrix with the gradient vector computed at each observation.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663

Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

See Also

alfa.sar, cv.alfasar, alfa.reg

Examples

data(fadn)
coords <- fadn[, 1:2]
y <- fadn[, 3:7]
x <- fadn[, 8:10]

be <- matrix( c( 12.72191991, 0.04300266, -1.78301001, -3.02074120, -23.54785921,
0.06771573, 2.71969599, 1.89312564, 5.38640736, 0.05179626, -1.21336879, 0.40175088,
-1.98258721, 0.06815682, -0.64458883, 0.95470802 ), ncol = 4 )

CompositionalSR documentation built on March 28, 2026, 5:07 p.m.