cv.alfareg: K-fold cross-validation for the alpha-regression

View source: R/cv.alfareg.R

K-fold cross-validation for the alpha-regressionR Documentation

K-fold cross-validation for the \alpha-regression

Description

K-fold cross-validation for the \alpha-regression.

Usage

cv.alfareg(y, x, a = seq(0.1, 1, by = 0.1), nfolds = 10,
folds = NULL, nc = 1, seed = NULL)

Arguments

y

A matrix with compositional data. zero values are allowed.

x

A matrix with the continuous predictor variables or a data frame including categorical predictor variables.

a

The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0. If \alpha=0 the isometric log-ratio transformation is applied.

nfolds

The number of folds to split the data.

folds

If you have the list with the folds supply it here. You can also leave it NULL and it will create folds.

nc

The number of cores to use. IF you have a multicore computer it is advisable to use more than 1. It makes the procedure faster. It is advisable to use it if you have many observations and or many variables, otherwise it will slow down th process.

seed

You can specify your own seed number here or leave it NULL.

Details

Tuning the value of \alpha in the \alpha-regression takes place using K-fold cross-validation.

Value

A list including:

runtime

The runtime required by the cross-validation.

perf

A vector with the average Kullback-Leibler divergence, for every value of \alpha.

opt

A vector with the minimum Kullback-Leibler divergence and the optimal value of \alpha.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663

Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

See Also

alfa.reg, cv.alfaslx, cv.gwar, me.ar

Examples

data(fadn)
y <- fadn[, 3:7]
x <- fadn[, 8]
mod <- cv.alfareg(y, x, a = c(0.5, 1))

CompositionalSR documentation built on March 28, 2026, 5:07 p.m.