gwar: The GWalphaR model

View source: R/gwar.R

The GWaR modelR Documentation

The GW\alphaR model

Description

The GW\alphaR model.

Usage

gwar(y, x, a, coords, h, yb = NULL, nc = 1)

Arguments

y

A matrix with the compositional data.

x

A matrix with the continuous predictor variables or a data frame including categorical predictor variables.

a

The value of the power transformation, it has to be between -1 and 1.

coords

A matrix with the coordinates of the locations. The first column is the latitude and the second is the longitude.

h

The bandwith value.

yb

If you have already transformed the data using the \alpha-transformation with the same \alpha as given in the argument "a", put it here. Othewrise leave it NULL.

nc

The number of cores to use. IF you have a multicore computer it is advisable to use more than 1. It makes the procedure faster. It is advisable to use it if you have many observations and or many variables, otherwise it will slow down th process.

Details

The \alpha-transformation is applied to the compositional data first and then the GW\alphaR model is applied.

Value

A list including:

runtime

The time required by the regression.

be

The beta coefficients.

est

The fitted values.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663

Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

See Also

cv.gwar, me.gwar, alfa.slx, alfa.reg

Examples

data(fadn)
coords <- fadn[, 1:2]
y <- fadn[, 3:7]
x <- fadn[, 8]
mod <- gwar(y, x, a = 1, coords, h = 0.001)

CompositionalSR documentation built on March 28, 2026, 5:07 p.m.