| Prediction with the GWalphaR model | R Documentation |
\alphaR model
Prediction with GW\alphaR model.
gwar.pred(y, x, a, coords, h, xnew, coordsnew)
y |
A matrix with the compositional data. |
x |
A matrix with the continuous predictor variables or a data frame including categorical predictor variables. |
a |
A vector with values for the power transformation, it has to be between -1 and 1. |
coords |
A matrix with the coordinates of the locations. The first column is the latitude and the second is the longitude. |
h |
A vector with bandwith values. |
xnew |
The new data. |
coordsnew |
A matrix with the coordinates of the new locations. The first column is the latitude and the second is the longitude. |
The \alpha-transformation is applied to the compositional data first and then the GW\alphaR model is applied and predictions are given for each observation.
A list including:
runtime |
The time required by the regression. |
est |
A list with the fitted values, for each combination of |
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models.
https://arxiv.org/pdf/2510.12663
Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf
Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf
cv.gwar, me.gwar, alfa.slx, alfa.reg
data(fadn)
coords <- fadn[-c(1:10), 1:2]
y <- fadn[-c(1:10), 3:7]
x <- fadn[-c(1:10), 8]
xnew <- fadn[1:10, 8]
coordsnew <- fadn[1:10, 1:2]
mod <- gwar.pred(y, x, a = c(0.25, 0.5, 1), coords,
h = c(0.002, 0.006), xnew = xnew, coordsnew = coordsnew)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.