me.ar: Marginal effects for the alpha-regression model

View source: R/me.ar.R

Marginal effects for the alpha-regression modelR Documentation

Marginal effects for the \alpha-regression model

Description

Marginal effects for the \alpha-regression model.

Usage

me.ar(be, mu, x, cov_be = NULL)

Arguments

be

A matrix with the beta regression coefficients of the \alpha-regression model.

mu

The fitted values of the \alpha-regression.

x

A matrix with the continuous predictor variables or a data frame. Categorical predictor variables are not suited here.

cov_be

The covariance matrix of the beta regression coefficients. If you pass this argument, then the standard error of the average marginal effects will be returned.

Details

The marginal effects of the \alpha-regression model are computed.

Value

A list including:

me

An array with the marginal effects of each component for each predictor variable.

ame

The average marginal effects of each component for each predictor variable.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663

Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

See Also

me.aslx, me.gwar, alfa.reg

Examples

data(fadn)
y <- fadn[, 3:7]
x <- fadn[, 8]
mod <- alfa.reg(y, x, 0.2, xnew = x)
me <- me.ar(mod$be, mod$est, x)

CompositionalSR documentation built on March 28, 2026, 5:07 p.m.