rob.alfareg: Regression with compositional data using the...

View source: R/rob.alfareg.R

Robust regression with compositional data using the alpha-transformationR Documentation

Regression with compositional data using the \alpha-transformation

Description

Regression with compositional data using the \alpha-transformation.

Usage

rob.alfareg(y, x, a, loss = "welsh", xnew = NULL, yb = NULL)

Arguments

y

A matrix with the compositional data.

x

A matrix with the continuous predictor variables or a data frame including categorical predictor variables.

a

The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0. If \alpha=0 the isometric log-ratio transformation is applied and the solution exists in a closed form, since it the classical mutivariate regression.

loss

The loss function to use. One of these available options, "barron", "bisquare", "welsh", "optimal", "hampel", "ggw", or "lqq". For more information see the package gslnls.

xnew

If you have new data use it, otherwise leave it NULL.

yb

If you have already transformed the data using the \alpha-transformation with the same \alpha as given in the argument "a", put it here. Othewrise leave it NULL.

Details

The \alpha-transformation is applied to the compositional data first and then robust multivariate regression is applied. This involves numerical optimisation.

Value

A list including:

runtime

The time required by the regression.

be

The beta coefficients.

est

The fitted values for xnew if xnew is not NULL.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663

Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

Mardia K.V., Kent J.T., and Bibby J.M. (1979). Multivariate analysis. Academic press.

Aitchison J. (1986). The statistical analysis of compositional data. Chapman & Hall.

See Also

alfa.reg, alfareg.nr, alfa.slx

Examples

data(fadn)
y <- fadn[, 3:7]
x <- fadn[, 8]
mod <- rob.alfareg(y, x, 0.2)

CompositionalSR documentation built on March 28, 2026, 5:07 p.m.