Regression with compositional data using the \(\alpha\)-transformation.
rob.alfareg(y, x, a, loss = "welsh", xnew = NULL, yb = NULL)A list including:
The time required by the regression.
The beta coefficients.
The fitted values for xnew if xnew is not NULL.
A matrix with the compositional data.
A matrix with the continuous predictor variables or a data frame including categorical predictor variables.
The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0. If \(\alpha=0\) the isometric log-ratio transformation is applied and the solution exists in a closed form, since it the classical mutivariate regression.
The loss function to use. One of these available options, "barron", "bisquare", "welsh", "optimal", "hampel", "ggw", or "lqq". For more information see the package gslnls.
If you have new data use it, otherwise leave it NULL.
If you have already transformed the data using the \(\alpha\)-transformation with the same \(\alpha\) as given in the argument "a", put it here. Othewrise leave it NULL.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
The \(\alpha\)-transformation is applied to the compositional data first and then robust multivariate regression is applied. This involves numerical optimisation.
Tsagris M. (2025). The \(\alpha\)--regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663
Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf
Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf
Mardia K.V., Kent J.T., and Bibby J.M. (1979). Multivariate analysis. Academic press.
Aitchison J. (1986). The statistical analysis of compositional data. Chapman & Hall.
alfa.reg, alfareg.nr, alfa.slx
data(fadn)
y <- fadn[, 3:7]
x <- fadn[, 8]
mod <- rob.alfareg(y, x, 0.2)
Run the code above in your browser using DataLab