The \(\alpha\)-SAR model.
alfa.sar(y, x, a, coords, k = 10, covb = FALSE, xnew = NULL, coordsnew, yb = NULL)A list including:
The time required by the regression.
The beta coefficients.
The gamma coefficients.
The covariance matrix if covb was set to TRUE, otherwise NULL.
The sum of the squared residuals, as produced by the function minpack.lm::nls.lm().
The fitted values for xnew if xnew and coordsnew are not NULL.
A matrix with the compositional data.
A matrix with the continuous predictor variables or a data frame including categorical predictor variables.
The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0. If \(\alpha=0\) the isometric log-ratio transformation is applied and the solution exists in a closed form, since it the classical mutivariate regression.
A matrix with the coordinates of the locations. The first column is the latitude and the second is the longitude.
The number of nearest neighbours to consider for the contiguity matrix.
Do you want the covariance matrix of the spatial autoregressive parameter and the regression coefficients to be returned? If TRUE, this will slow down the process, as it is computed numerically.
If you have new data use it, otherwise leave it NULL.
A matrix with the coordinates of the new locations. The first column is the latitude and the second is the longitude. If you do not have new data to make predictions leave this NULL.
If you have already transformed the data using the \(\alpha\)-transformation with the same \(\alpha\) as given in the argument "a", put it here. Othewrise leave it NULL.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
The \(\alpha\)-transformation is applied to the compositional data first and the spatial autocorrelation (SAR) model is applied. The function performs a grid search searching for the range of good values of \(\rho\) and then uses that as starting value.
Tsagris M. (2025). The \(\alpha\)--regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models. https://arxiv.org/pdf/2510.12663
Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf
Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf
cv.alfaslx, me.aslx, gwar, alfa.reg
data(fadn)
coords <- fadn[1:50, 1:2]
y <- fadn[1:50, 3:7]
x <- fadn[1:50, 8]
Run the code above in your browser using DataLab