| K-fold cross-validation for the alpha-regression with compositional predictors | R Documentation |
\alpha-regression with compositional predictors
K-fold cross-validation the \alpha-regression with compositional predictors.
cv.alfapcreg(y, x, a = seq(0.1, 1, by = 0.1), nfolds = 10, folds = NULL, seed = NULL)
y |
A matrix with compositional response data. Zero values are allowed. |
x |
A matrix with the compositional predictor variables. Zero values are allowed. |
a |
A numerical vector with the values of the power transformation, it has to be between -1 and 1.
If zero values are present it has to be greater than 0. If |
nfolds |
The number of folds to split the data. |
folds |
If you have the list with the folds supply it here. You can also leave it NULL and it will create folds. |
seed |
You can specify your own seed number here or leave it NULL. |
Tuning the value of \alpha and k, the number of principal components in the
\alpha-regression with compositional predictors takes place using the
classical K-fold cross-validation.
A list including:
runtime |
The runtime required by the cross-validation. |
perf |
A matrix with the average Kullback-Leibler divergence, for every value of |
kl |
The minimum average value of the Kullback-Leibler divergence. |
opt_a |
The optimal value of |
opt_k |
The optimal value of k, the number of principal components. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models.
https://arxiv.org/pdf/2510.12663
Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf
Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf
alfa.pcreg, cv.alfareg
data(fadn)
y <- fadn[, 3:7]
x <- fadn[, 8:11]
x <- x / rowSums(x)
mod <- cv.alfapcreg(y, x, a = c(0.5, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.