| ICE plot for the alpha-regression | R Documentation |
\alpha-regression
ICE plot for the \alpha-regression.
ice.areg(be, x, ind = 1, frac = 0.25, pos = 0.5)
be |
A numerical matrix with the estimated |
x |
A numerical matrix with the predictor variables. |
ind |
Which variable to select?. |
frac |
Fraction of observations to use. The default value is 0.25. |
pos |
This is a number between 0 and 1 and is used to place the legend in the appropriate place. |
This function implements the Individual Conditional Expecation plots of Goldstein et al. (2015). See the references for more details.
A graph with several curves, one for each component. The horizontal axis contains the selected variable, whereas the vertical axis contains the locally smoothed predicted compositional lines.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
https://christophm.github.io/interpretable-ml-book/ice.html
Goldstein, A., Kapelner, A., Bleich, J. and Pitkin, E. (2015). Peeking inside the black box: Visualizing statistical learning with plots of individual conditional expectation. Journal of Computational and Graphical Statistics 24(1): 44-65.
areg, cv.alfareg
data(fadn)
y <- fadn[, 3:7]
x <- fadn[, 8, drop = FALSE]
mod <- alfa.reg(y, x, 0.2)
ice <- ice.areg(mod$be, x, ind = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.