| Marginal effects for the alpha-SAR model | R Documentation |
\alpha-SAR model
Marginal effects for the \alpha-SAR model.
me.asar(be, rho, mu, x, coords, k, cov_theta = NULL)
be |
A matrix with the beta coefficients of the |
rho |
The spatial auto-regressive coefficient |
mu |
The fitted values of the |
x |
A matrix with the continuous predictor variables or a data frame. Categorical predictor variables are not suited here. |
coords |
A matrix with the coordinates of the locations. The first column is the latitude and the second is the longitude. |
k |
The number of nearest neighbours to consider for the contiguity matrix. |
cov_theta |
The covariance matrix of the beta and gamma regression coefficients. If you pass this argument, then the standard error of the average marginal effects will be returned. |
The marginal effects of the \alpha-SAR model are computed.
A list including:
me.dir |
An array with the direct marginal effects of each component for each predictor variable. |
me.indir |
An array with the indirect marginal effects of each component for each predictor variable. |
me.total |
An array with the total marginal effects of each component for each predictor variable. |
ame.dir |
An array with the average direct marginal effects of each component for each predictor variable. |
ame.indir |
An array with the average indirect marginal effects of each component for each predictor variable. |
ame.total |
An array with the aerage total marginal effects of each component for each predictor variable. |
se.amedir |
An array with the standard errors of the average direct marginal effects of each component for each predictor variable. This is returned if you supply the covariance matrix cov_theta. |
se.ameindir |
An array with the standard errors of the average indirect marginal effects of each component for each predictor variable. This is returned if you supply the covariance matrix cov_theta. |
se.ametotal |
An array with the standard errors of the average total marginal effects of each component for each predictor variable. This is returned if you supply the covariance matrix cov_theta. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Tsagris M. and Pantazis Y. (2026). The \alpha–regression for compositional data: a unified framework for standard, spatially-lagged, spatial autoregressive and geographically-weighted regression models.
https://arxiv.org/pdf/2510.12663
Tsagris M. (2015). Regression analysis with compositional data containing zero values. Chilean Journal of Statistics, 6(2): 47-57. https://arxiv.org/pdf/1508.01913v1.pdf
Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf
me.ar, me.aslx, me.gwar
data(fadn)
coords <- fadn[, 1:2]
y <- fadn[, 3:7]
x <- fadn[, 8]
mod <- alfa.sar(y, x, a = 0.5, coords, k = 8)
me <- me.asar(mod$be, mod$rho, mod$est, x, coords, k = 6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.